@@ -93,14 +93,11 @@ sub mmn_eq {
     my($class, $dir) = @_;
 #    return 1 if $Is_Win32; #just assume, till Apache::src works under win32 
     my $instsrc;
-    {
-	local @INC = grep { !/blib/ } @INC;
-	my $instdir;
-        for (@INC) { 
-            last if -d ($instdir = "$_/auto/Apache/include"); 
-        } 
-	$instsrc = $class->new(dir => $instdir);
-    }
+    my $instdir;
+    for (@INC) { 
+        last if -d ($instdir = "$_/auto/Apache/include"); 
+    } 
+    $instsrc = $class->new(dir => $instdir);
     my $targsrc = $class->new($dir ? (dir => $dir) : ()); 
  
     my $inst_mmn = $instsrc->module_magic_number; 
