@@ -513,8 +513,15 @@ void mp_check_version(void)
 
     require_Apache(NULL);
 
-    if(!(version = perl_get_sv("Apache::VERSION", FALSE)))
-	croak("Apache.pm failed to load!"); /*should never happen*/
+    if(!(version = perl_get_sv("Apache::VERSION", FALSE))) {
+        /* should never happen but might if the perl mod_perl
+         * was built with isn't around anymore
+         */
+	croak("Apache.pm failed to load! (%s)",
+                  SvTRUE(ERRSV) ? SvPV(ERRSV,na) : "no error?"
+              );
+    }
+
     if(strEQ(SvPV(version,n_a), MP_APACHE_VERSION)) /*no worries*/
 	return;
 
@@ -707,6 +714,13 @@ void perl_startup (server_rec *s, pool *p)
     }
     MP_TRACE_g(fprintf(stderr, "ok\n"));
 
+#if (PERL_REVISION == 5) && (PERL_VERSION == 8) && (PERL_SUBVERSION == 1) && \
+    (defined(USE_HASH_SEED) || defined(USE_HASH_SEED_EXPLICIT))
+    /* bug in 5.8.1, causing all forked procs to produce the same rand
+     * sequence */
+    PL_srand_called = FALSE;
+#endif
+    
     perl_clear_env();
     mod_perl_pass_env(p, cls);
     mod_perl_set_cwd();
