@@ -392,7 +392,11 @@ static char *sigsave[] = { "ALRM", NULL };
 
 perl_request_config *perl_create_request_config(pool *p, server_rec *s)
 {
+
+#ifndef WIN32
     int i;
+#endif
+
     perl_request_config *cfg = 
 	(perl_request_config *)pcalloc(p, sizeof(perl_request_config));
     cfg->pnotes = Nullhv;
@@ -437,6 +441,13 @@ static void mp_preload_module(char **name)
 }
 #endif
 
+#define STARTUP_PERL_IF_NOT_RUNNING \
+if(!PERL_RUNNING()) { \
+    perl_startup(parms->server, parms->pool); \
+    require_Apache(parms->server); \
+    MP_TRACE_g(fprintf(stderr, "mod_perl: calling perl_startup()\n")); \
+}
+
 #ifdef PERL_STACKED_HANDLERS
 
 CHAR_P perl_cmd_push_handlers(char *hook, PERL_CMD_TYPE **cmd, char *arg, pool *p)
@@ -456,16 +467,13 @@ CHAR_P perl_cmd_push_handlers(char *hook, PERL_CMD_TYPE **cmd, char *arg, pool *
 }
 
 #define PERL_CMD_PUSH_HANDLERS(hook, cmd) \
-if(!PERL_RUNNING()) { \
-    perl_startup(parms->server, parms->pool); \
-    require_Apache(parms->server); \
-    MP_TRACE_g(fprintf(stderr, "mod_perl: calling perl_startup()\n")); \
-} \
+STARTUP_PERL_IF_NOT_RUNNING \
 return perl_cmd_push_handlers(hook,&cmd,arg,parms->pool)
 
 #else
 
 #define PERL_CMD_PUSH_HANDLERS(hook, cmd) \
+STARTUP_PERL_IF_NOT_RUNNING \
 mp_preload_module(&arg); \
 cmd = arg; \
 return NULL
@@ -1528,7 +1536,7 @@ void perl_handle_command_av(AV *av, I32 n, char *key, cmd_parms *cmd, void *conf
 {
     I32 alen = AvFILL(av);
     I32 i, j;
-    I32 oldwarn = dowarn; /*XXX, hmm*/
+    U8 oldwarn = dowarn; /*XXX, hmm*/
     dowarn = FALSE;
 
     if(!n) n = alen+1;
