@@ -1,64 +1,71 @@
 /* ====================================================================
- * Copyright (c) 1995-1997 The Apache Group.  All rights reserved.
+ * The Apache Software License, Version 1.1
+ *
+ * Copyright (c) 1996-2000 The Apache Software Foundation.  All rights
+ * reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in
  *    the documentation and/or other materials provided with the
  *    distribution.
  *
- * 3. All advertising materials mentioning features or use of this
- *    software must display the following acknowledgment:
- *    "This product includes software developed by the Apache Group
- *    for use in the Apache HTTP server project (http://www.apache.org/)."
+ * 3. The end-user documentation included with the redistribution,
+ *    if any, must include the following acknowledgment:
+ *       "This product includes software developed by the
+ *        Apache Software Foundation (http://www.apache.org/)."
+ *    Alternately, this acknowledgment may appear in the software itself,
+ *    if and wherever such third-party acknowledgments normally appear.
  *
- * 4. The names "Apache Server" and "Apache Group" must not be used to
- *    endorse or promote products derived from this software without
- *    prior written permission.
+ * 4. The names "Apache" and "Apache Software Foundation" must
+ *    not be used to endorse or promote products derived from this
+ *    software without prior written permission. For written
+ *    permission, please contact apache@apache.org.
  *
- * 5. Redistributions of any form whatsoever must retain the following
- *    acknowledgment:
- *    "This product includes software developed by the Apache Group
- *    for use in the Apache HTTP server project (http://www.apache.org/)."
+ * 5. Products derived from this software may not be called "Apache",
+ *    nor may "Apache" appear in their name, without prior written
+ *    permission of the Apache Software Foundation.
  *
- * THIS SOFTWARE IS PROVIDED BY THE APACHE GROUP ``AS IS'' AND ANY
- * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
- * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE APACHE GROUP OR
+ * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
+ * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
  * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
- * OF THE POSSIBILITY OF SUCH DAMAGE.
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
+ * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+ * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
+ * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
+ * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
  * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Group and was originally based
- * on public domain software written at the National Center for
- * Supercomputing Applications, University of Illinois, Urbana-Champaign.
- * For more information on the Apache Group and the Apache HTTP server
- * project, please see <http://www.apache.org/>.
- *
  */
 
 #include "mod_perl.h"
 
 #define dHANDLE(name) GV *handle = gv_fetchpv(name, TRUE, SVt_PVIO)
 
+#ifdef PERL_REVISION
+#   if ((PERL_REVISION == 5) && (PERL_VERSION >= 7))
+#      define TIEHANDLE_SV(handle) (SV*)GvIOp((SV*)handle)
+#   endif
+#endif
+
+#ifndef TIEHANDLE_SV
+#   define TIEHANDLE_SV(handle) (SV*)handle
+#endif
+
 #define TIEHANDLE(name,obj) \
 { \
       dHANDLE(name); \
-      sv_unmagic((SV*)handle, 'q'); \
-      sv_magic((SV*)handle, obj, 'q', Nullch, 0); \
+      sv_unmagic(TIEHANDLE_SV(handle), 'q'); \
+      sv_magic(TIEHANDLE_SV(handle), obj, 'q', Nullch, 0); \
 }
 
 #if 0
@@ -96,7 +103,7 @@ typedef struct {
 
 static int sfapachewrite(f, buffer, n, disc)
     Sfio_t* f;      /* stream involved */
-    char*           buffer;    /* buffer to read into */
+    char*           buffer;    /* buffer to write from */
     int             n;      /* number of bytes to send */
     Sfdisc_t*       disc;   /* discipline */        
 {
@@ -109,7 +116,7 @@ static int sfapachewrite(f, buffer, n, disc)
     XPUSHs(perl_bless_request_rec(((Apache_t*)disc)->r));
     XPUSHs(sv_2mortal(newSVpv(buffer,n)));
     PUTBACK;
-    (void)(*CvXSUB(cv))(cv); 
+    (void)(*CvXSUB(cv))(aTHXo_ cv); 
     FREETMPS;
     LEAVE;
     return n;
@@ -121,11 +128,40 @@ static int sfapacheread(f, buffer, bufsiz, disc)
     int             bufsiz;      /* number of bytes to read */
     Sfdisc_t*       disc;   /* discipline */        
 {
-    long nrd;
-    request_rec	*r = ((Apache_t*)disc)->r;
+    dSP;
+    int count;
+    int nrd;
+    SV *sv = sv_newmortal();
+    request_rec *r = ((Apache_t*)disc)->r;
     MP_TRACE_g(fprintf(stderr, "sfapacheread: want %d bytes\n", bufsiz)); 
-    PERL_READ_FROM_CLIENT;
-    return bufsiz;
+    ENTER;SAVETMPS;
+    PUSHMARK(sp);
+    XPUSHs(perl_bless_request_rec(r));
+    XPUSHs(sv);
+    XPUSHs(sv_2mortal(newSViv(bufsiz)));
+    PUTBACK;
+    count = perl_call_pv("Apache::read", G_SCALAR|G_EVAL);
+    SPAGAIN;
+    if (SvTRUE(ERRSV)) {
+	fprintf (stderr, "Apache::read died %s\n", SvPV(ERRSV, na));
+	nrd = -1;
+	POPs;
+    }
+    else {
+        char *tmpbuf = SvPV(sv, nrd);
+        if(count == 1) {
+	    nrd = POPi;
+	}
+	MP_TRACE_g(fprintf(stderr, "sfapacheread: got %d \"%.*s\"\n",
+			   nrd, nrd > 40 ? 40 : nrd, tmpbuf));
+        if (nrd > bufsiz) {
+	    abort();
+	}
+	memcpy(buffer, tmpbuf, nrd);
+    }
+    PUTBACK;
+    FREETMPS;LEAVE;
+    return nrd;
 }
 
 Sfdisc_t * sfdcnewapache(request_rec *r)
