@@ -1,7 +1,7 @@
 #PerlOpmask default
 
 <IfModule mod_dll.c>
-LoadModule perl_module modules/ApacheModulePerl.dll
+LoadModule perl_module modules/mod_perl.so
 </IfModule>
 
 AddType text/x-server-parsed-html .shtml
@@ -120,7 +120,7 @@ $ServerName = "localhost";
 
 push @AddType, ["text/x-server-parsed-html" => ".shtml"];
  
-for (qw(/perl /cgi-bin /dirty-perl /perl_xs)) {
+for (qw(/perl /cgi-bin /dirty-perl /perl_xs /ng-perl)) {
     push @Alias, [$_ => "$dir/net/perl/"];
 }
 
@@ -141,6 +141,13 @@ $Location{"/dirty-perl"} = {
     PerlSendHeader => "On",
 };
 
+$Location{"/ng-perl"} = { 
+    SetHandler => "perl-script",
+    PerlHandler => "Apache::RegistryNG",
+    Options => "+ExecCGI ",
+    PerlSendHeader => "On",
+};
+
 for (qw(perl perl_xs)) {
     $Location{"/$_"} = { 
 	@mod_perl,
@@ -156,11 +163,34 @@ for (qw(perl perl_xs)) {
     };
 }
 
-$Location{"/cgi-bin"} = {
+$LocationMatch{"/(cgi|slow)-bin"} = {
     SetHandler => "cgi-script",
     Options    => "ExecCGI",
 };
 
+sub My::Files::handler {
+    my $r = shift;
+    $r->send_http_header('text/plain');
+    printf "%s pulled out of thin air at %s",
+           $r->filename, scalar localtime $r->request_time;
+}
+
+sub My::Directory::handler {
+    my $r = shift;
+    $r->send_http_header('text/plain');
+    printf "%s says to take a hike", $r->filename =~ m:(\w+)/public:;
+}
+
+$FilesMatch{".(date|time)\$"} = {
+    SetHandler => 'perl-script',
+    PerlHandler => 'My::Files',
+};
+
+$DirectoryMatch{"public_html"} = {
+    SetHandler => 'perl-script',
+    PerlHandler => 'My::Directory',
+};
+
 #just make sure we can parse this
 
 chomp(my $hostname = `hostname`);
